/***********************************************************************
 * FXRuby -- the Ruby language bindings for the FOX GUI toolkit.
 * Copyright (c) 2001-2003 by J. Lyle Johnson. All Rights Reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * For further information please contact the author by e-mail
 * at "lyle@users.sourceforge.net".
 ***********************************************************************/

/***********************************************************************
 * $Id: FXRbIconSource.h 2157 2005-08-20 04:32:36Z lyle $
 ***********************************************************************/

#ifndef FXRBICONSOURCE_H
#define FXRBICONSOURCE_H

#define DECLARE_FXICONSOURCE_STUBS(cls) \
inline FXIcon* cls ## _loadIcon(const cls* self,const FXString& filename,const FXString& type){ \
  return self->cls::loadIcon(filename,type); \
  } \
inline FXIcon* cls ## _loadIcon(const cls* self,const void* pixels,const FXString& type){ \
  return self->cls::loadIcon(pixels,type); \
  } \
inline FXIcon* cls ## _loadIcon(const cls* self,FXStream& store,const FXString& type){ \
  return self->cls::loadIcon(store,type); \
  } \
inline FXImage* cls ## _loadImage(const cls* self,const FXString& filename,const FXString& type){ \
  return self->cls::loadImage(filename,type); \
  } \
inline FXImage* cls ## _loadImage(const cls* self,const void* pixels,const FXString& type){ \
  return self->cls::loadImage(pixels,type); \
  } \
inline FXImage* cls ## _loadImage(const cls* self,FXStream& store,const FXString& type){ \
  return self->cls::loadImage(store,type); \
  } \
inline FXIcon* cls ## _loadScaledIcon(const cls* self,const FXString& filename,FXint size,FXint qual,const FXString& type){ \
  return self->cls::loadScaledIcon(filename,size,qual,type); \
  } \
inline FXIcon* cls ## _loadScaledIcon(const cls* self,const void* pixels,FXint size,FXint qual,const FXString& type){ \
  return self->cls::loadScaledIcon(pixels,size,qual,type); \
  } \
inline FXIcon* cls ## _loadScaledIcon(const cls* self,FXStream& store,FXint size,FXint qual,const FXString& type){ \
  return self->cls::loadScaledIcon(store,size,qual,type); \
  } \
inline FXImage* cls ## _loadScaledImage(const cls* self,const FXString& filename,FXint size,FXint qual,const FXString& type){ \
  return self->cls::loadScaledImage(filename,size,qual,type); \
  } \
inline FXImage* cls ## _loadScaledImage(const cls* self,const void* pixels,FXint size,FXint qual,const FXString& type){ \
  return self->cls::loadScaledImage(pixels,size,qual,type); \
  } \
inline FXImage* cls ## _loadScaledImage(const cls* self,FXStream& store,FXint size,FXint qual,const FXString& type){ \
  return self->cls::loadScaledImage(store,size,qual,type); \
  }


#define IMPLEMENT_FXICONSOURCE_STUBS(cls) \
  FXIcon* cls::loadIcon(const FXString& filename,const FXString& type) const { \
    return FXRbCallIconMethod(this,rb_intern("loadIcon"),filename,type); \
    } \
  FXIcon* cls::loadIcon(const void* pixels,const FXString& type) const { \
    return FXRbCallIconMethod(this,rb_intern("loadIcon"),pixels,type); \
    } \
  FXIcon* cls::loadIcon(FXStream& store,const FXString& type) const { \
    return FXRbCallIconMethod(this,rb_intern("loadIcon"),store,type); \
    } \
  FXImage* cls::loadImage(const FXString& filename,const FXString& type) const { \
    return FXRbCallImageMethod(this,rb_intern("loadImage"),filename,type); \
    } \
  FXImage* cls::loadImage(const void* pixels,const FXString& type) const { \
    return FXRbCallImageMethod(this,rb_intern("loadImage"),pixels,type); \
    } \
  FXImage* cls::loadImage(FXStream& store,const FXString& type) const { \
    return FXRbCallImageMethod(this,rb_intern("loadImage"),store,type); \
    } \
  FXIcon* cls::loadScaledIcon(const FXString& filename,FXint size,FXint qual,const FXString& type) const { \
    return FXRbCallIconMethod(this,rb_intern("loadScaledIcon"),filename,size,qual,type); \
    } \
  FXIcon* cls::loadScaledIcon(const void* pixels,FXint size,FXint qual,const FXString& type) const { \
    return FXRbCallIconMethod(this,rb_intern("loadScaledIcon"),pixels,size,qual,type); \
    } \
  FXIcon* cls::loadScaledIcon(FXStream& store,FXint size,FXint qual,const FXString& type) const { \
    return FXRbCallIconMethod(this,rb_intern("loadScaledIcon"),store,size,qual,type); \
    } \
  FXImage* cls::loadScaledImage(const FXString& filename,FXint size,FXint qual,const FXString& type) const { \
    return FXRbCallImageMethod(this,rb_intern("loadScaledImage"),filename,size,qual,type); \
    } \
  FXImage* cls::loadScaledImage(const void* pixels,FXint size,FXint qual,const FXString& type) const { \
    return FXRbCallImageMethod(this,rb_intern("loadScaledImage"),pixels,size,qual,type); \
    } \
  FXImage* cls::loadScaledImage(FXStream& store,FXint size,FXint qual,const FXString& type) const { \
    return FXRbCallImageMethod(this,rb_intern("loadScaledImage"),store,size,qual,type); \
    }


class FXRbIconSource : public FXIconSource {
  FXDECLARE(FXRbIconSource)
protected:
  FXRbIconSource(){}
#include "FXRbObjectVirtuals.h"
#include "FXRbIconSourceVirtuals.h"
public:
  // Constructor
  FXRbIconSource(FXApp* app) : FXIconSource(app){}

  // Mark dependencies for the GC
  static void markfunc(FXIconSource* self);

  // Destructor
  virtual ~FXRbIconSource(){
    FXRbUnregisterRubyObj(this);
    }
  };

#endif
